aboutsummaryrefslogtreecommitdiffstats
path: root/calendar
diff options
context:
space:
mode:
authorRodrigo Moya <rodrigo@ximian.com>2002-11-08 00:18:38 +0800
committerRodrigo Moya <rodrigo@src.gnome.org>2002-11-08 00:18:38 +0800
commit55434d946738ae03c2c841002204baa3bdd7ce1f (patch)
treed213f5a38ccfe18b2f86dd37a51e352e235842e9 /calendar
parentff4b4e7ed3c2450a7d9d565f7ef1a734f009710e (diff)
downloadgsoc2013-evolution-55434d946738ae03c2c841002204baa3bdd7ce1f.tar
gsoc2013-evolution-55434d946738ae03c2c841002204baa3bdd7ce1f.tar.gz
gsoc2013-evolution-55434d946738ae03c2c841002204baa3bdd7ce1f.tar.bz2
gsoc2013-evolution-55434d946738ae03c2c841002204baa3bdd7ce1f.tar.lz
gsoc2013-evolution-55434d946738ae03c2c841002204baa3bdd7ce1f.tar.xz
gsoc2013-evolution-55434d946738ae03c2c841002204baa3bdd7ce1f.tar.zst
gsoc2013-evolution-55434d946738ae03c2c841002204baa3bdd7ce1f.zip
converted to BonoboObject.
2002-11-07 Rodrigo Moya <rodrigo@ximian.com> * cal-client/query-listener.[ch]: converted to BonoboObject. * gui/dialogs/comp-editor-util.c (parse_contact_string): use glib's g_utf8_strchr. * gui/dialogs/delete-comp.c: removed non-existant headers. Use GtkStock instead of GnomeStock. * gui/dialogs/e-delegate-dialog.c: converted to BonoboActivation. (e_delegate_dialog_construct): adapted to changes in glade_xml_new. svn path=/trunk/; revision=18632
Diffstat (limited to 'calendar')
-rw-r--r--calendar/ChangeLog13
-rw-r--r--calendar/cal-client/query-listener.c34
-rw-r--r--calendar/cal-client/query-listener.h17
-rw-r--r--calendar/gui/dialogs/comp-editor-util.c4
-rw-r--r--calendar/gui/dialogs/delete-comp.c7
-rw-r--r--calendar/gui/dialogs/e-delegate-dialog.c6
-rw-r--r--calendar/gui/dialogs/e-delegate-dialog.h1
7 files changed, 46 insertions, 36 deletions
diff --git a/calendar/ChangeLog b/calendar/ChangeLog
index 16cf51dbf5..ba9603182f 100644
--- a/calendar/ChangeLog
+++ b/calendar/ChangeLog
@@ -1,5 +1,18 @@
2002-11-07 Rodrigo Moya <rodrigo@ximian.com>
+ * cal-client/query-listener.[ch]: converted to BonoboObject.
+
+ * gui/dialogs/comp-editor-util.c (parse_contact_string): use glib's
+ g_utf8_strchr.
+
+ * gui/dialogs/delete-comp.c: removed non-existant headers. Use
+ GtkStock instead of GnomeStock.
+
+ * gui/dialogs/e-delegate-dialog.c: converted to BonoboActivation.
+ (e_delegate_dialog_construct): adapted to changes in glade_xml_new.
+
+2002-11-07 Rodrigo Moya <rodrigo@ximian.com>
+
* pcs/cal.[ch]: converted to BonoboObject.
(impl_Cal_get_query): bonobo_object_unref the query returned by
cal_backend_get_query if we can't duplicate it.
diff --git a/calendar/cal-client/query-listener.h b/calendar/cal-client/query-listener.h
index ab59345cf4..eeb42afc7e 100644
--- a/calendar/cal-client/query-listener.h
+++ b/calendar/cal-client/query-listener.h
@@ -21,8 +21,7 @@
#ifndef QUERY_LISTENER_H
#define QUERY_LISTENER_H
-#include <gtk/gtkobject.h>
-#include <bonobo/bonobo-xobject.h>
+#include <bonobo/bonobo-object.h>
#include "evolution-calendar.h"
G_BEGIN_DECLS
@@ -30,23 +29,23 @@ G_BEGIN_DECLS
#define QUERY_LISTENER_TYPE (query_listener_get_type ())
-#define QUERY_LISTENER(obj) (GTK_CHECK_CAST ((obj), QUERY_LISTENER_TYPE, QueryListener))
-#define QUERY_LISTENER_CLASS(klass) (GTK_CHECK_CLASS_CAST ((klass), QUERY_LISTENER_TYPE, \
+#define QUERY_LISTENER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), QUERY_LISTENER_TYPE, QueryListener))
+#define QUERY_LISTENER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), QUERY_LISTENER_TYPE, \
QueryListenerClass))
-#define IS_QUERY_LISTENER(obj) (GTK_CHECK_TYPE ((obj), QUERY_LISTENER_TYPE))
-#define IS_QUERY_LISTENER_CLASS(klass) (GTK_CHECK_CLASS_TYPE ((klass), QUERY_LISTENER_TYPE))
+#define IS_QUERY_LISTENER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), QUERY_LISTENER_TYPE))
+#define IS_QUERY_LISTENER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), QUERY_LISTENER_TYPE))
typedef struct _QueryListenerPrivate QueryListenerPrivate;
typedef struct {
- BonoboXObject xobject;
+ BonoboObject xobject;
/* Private data */
QueryListenerPrivate *priv;
} QueryListener;
typedef struct {
- BonoboXObjectClass parent_class;
+ BonoboObjectClass parent_class;
POA_GNOME_Evolution_Calendar_QueryListener__epv epv;
} QueryListenerClass;
@@ -74,7 +73,7 @@ typedef void (* QueryListenerEvalErrorFn) (QueryListener *ql,
const CORBA_char *error_str,
gpointer data);
-GtkType query_listener_get_type (void);
+GType query_listener_get_type (void);
QueryListener *query_listener_construct (QueryListener *ql,
QueryListenerObjUpdatedFn obj_updated_fn,
diff --git a/calendar/gui/dialogs/comp-editor-util.c b/calendar/gui/dialogs/comp-editor-util.c
index 165cd43744..c60c416087 100644
--- a/calendar/gui/dialogs/comp-editor-util.c
+++ b/calendar/gui/dialogs/comp-editor-util.c
@@ -379,8 +379,8 @@ parse_contact_string (const char *value, char **name, char **email)
return;
}
- lbracket = g_utf8_strchr (value, '<');
- rbracket = g_utf8_strchr (value, '>');
+ lbracket = g_utf8_strchr (value, g_utf8_strlen (value, 0), '<');
+ rbracket = g_utf8_strchr (value, g_utf8_strlen (value, 0), '>');
if (!lbracket || !rbracket || rbracket < lbracket) {
*name = g_strdup (value);
diff --git a/calendar/gui/dialogs/delete-comp.c b/calendar/gui/dialogs/delete-comp.c
index 405a9445b4..f4606041f7 100644
--- a/calendar/gui/dialogs/delete-comp.c
+++ b/calendar/gui/dialogs/delete-comp.c
@@ -23,9 +23,8 @@
#endif
#include <glib.h>
-#include <libgnome/gnome-defs.h>
+#include <gtk/gtkstock.h>
#include <libgnome/gnome-i18n.h>
-#include <libgnomeui/gnome-stock.h>
#include <gal/widgets/e-unicode.h>
#include "widgets/misc/e-messagebox.h"
#include "../calendar-config.h"
@@ -151,8 +150,8 @@ delete_component_dialog (CalComponent *comp,
}
dialog = e_message_box_new (str, E_MESSAGE_BOX_QUESTION,
- GNOME_STOCK_BUTTON_YES,
- GNOME_STOCK_BUTTON_NO,
+ GTK_STOCK_YES,
+ GTK_STOCK_NO,
NULL);
g_free (str);
diff --git a/calendar/gui/dialogs/e-delegate-dialog.c b/calendar/gui/dialogs/e-delegate-dialog.c
index d37fbce51c..c42bd3ca95 100644
--- a/calendar/gui/dialogs/e-delegate-dialog.c
+++ b/calendar/gui/dialogs/e-delegate-dialog.c
@@ -20,7 +20,7 @@
*/
#include <config.h>
-#include <liboaf/liboaf.h>
+#include <bonobo-activation/bonobo-activation.h>
#include <bonobo/bonobo-control.h>
#include <bonobo/bonobo-exception.h>
#include <bonobo/bonobo-widget.h>
@@ -160,7 +160,7 @@ e_delegate_dialog_construct (EDelegateDialog *edd, const char *name, const char
/* Load the content widgets */
priv->xml = glade_xml_new (EVOLUTION_GLADEDIR "/e-delegate-dialog.glade",
- NULL);
+ NULL, NULL);
if (!priv->xml) {
g_message ("e_delegate_dialog_construct(): Could not load the Glade XML file!");
goto error;
@@ -173,7 +173,7 @@ e_delegate_dialog_construct (EDelegateDialog *edd, const char *name, const char
CORBA_exception_init (&ev);
- priv->corba_select_names = oaf_activate_from_id (SELECT_NAMES_OAFID, 0, NULL, &ev);
+ priv->corba_select_names = bonobo_activation_activate_from_id (SELECT_NAMES_OAFID, 0, NULL, &ev);
GNOME_Evolution_Addressbook_SelectNames_addSectionWithLimit (priv->corba_select_names,
section_name,
section_name,
diff --git a/calendar/gui/dialogs/e-delegate-dialog.h b/calendar/gui/dialogs/e-delegate-dialog.h
index 311d22b4c7..dc26327241 100644
--- a/calendar/gui/dialogs/e-delegate-dialog.h
+++ b/calendar/gui/dialogs/e-delegate-dialog.h
@@ -21,7 +21,6 @@
#ifndef __E_DELEGATE_DIALOG_H__
#define __E_DELEGATE_DIALOG_H__
-#include <libgnome/gnome-defs.h>
#include <gtk/gtkwidget.h>
diff --git a/calendar/cal-client/query-listener.c b/calendar/cal-client/query-listener.c
index 6f090717d7..6bd7bfc6f7 100644
--- a/calendar/cal-client/query-listener.c
+++ b/calendar/cal-client/query-listener.c
@@ -43,8 +43,8 @@ struct _QueryListenerPrivate {
static void query_listener_class_init (QueryListenerClass *class);
-static void query_listener_init (QueryListener *ql);
-static void query_listener_destroy (GtkObject *object);
+static void query_listener_init (QueryListener *ql, QueryListenerClass *class);
+static void query_listener_finalize (GObject *object);
static void impl_notifyObjUpdated (PortableServer_Servant servant,
const GNOME_Evolution_Calendar_CalObjUIDSeq *uids,
@@ -66,26 +66,26 @@ static void impl_notifyEvalError (PortableServer_Servant servant,
const CORBA_char *error_str,
CORBA_Environment *ev);
-static BonoboXObjectClass *parent_class;
+static BonoboObjectClass *parent_class;
-BONOBO_X_TYPE_FUNC_FULL (QueryListener,
- GNOME_Evolution_Calendar_QueryListener,
- BONOBO_X_OBJECT_TYPE,
- query_listener);
+BONOBO_TYPE_FUNC_FULL (QueryListener,
+ GNOME_Evolution_Calendar_QueryListener,
+ BONOBO_TYPE_OBJECT,
+ query_listener);
/* Class initialization function for the live search query listener */
static void
query_listener_class_init (QueryListenerClass *class)
{
- GtkObjectClass *object_class;
+ GObjectClass *object_class;
- object_class = (GtkObjectClass *) class;
+ object_class = (GObjectClass *) class;
- parent_class = gtk_type_class (BONOBO_X_OBJECT_TYPE);
+ parent_class = g_type_class_peek_parent (class);
- object_class->destroy = query_listener_destroy;
+ object_class->finalize = query_listener_finalize;
class->epv.notifyObjUpdated = impl_notifyObjUpdated;
class->epv.notifyObjRemoved = impl_notifyObjRemoved;
@@ -95,7 +95,7 @@ query_listener_class_init (QueryListenerClass *class)
/* Object initialization function for the live search query listener */
static void
-query_listener_init (QueryListener *ql)
+query_listener_init (QueryListener *ql, QueryListenerClass *class)
{
QueryListenerPrivate *priv;
@@ -111,9 +111,9 @@ query_listener_init (QueryListener *ql)
priv->notify = TRUE;
}
/* Destroy handler for the live search query listener */
static void
-query_listener_destroy (GtkObject *object)
+query_listener_finalize (GObject *object)
{
QueryListener *ql;
QueryListenerPrivate *priv;
@@ -135,8 +135,8 @@ query_listener_destroy (GtkObject *object)
g_free (priv);
ql->priv = NULL;
- if (GTK_OBJECT_CLASS (parent_class)->destroy)
- (* GTK_OBJECT_CLASS (parent_class)->destroy) (object);
+ if (G_OBJECT_CLASS (parent_class)->finalize)
+ (* G_OBJECT_CLASS (parent_class)->finalize) (object);
}
@@ -288,7 +288,7 @@ query_listener_new (QueryListenerObjUpdatedFn obj_updated_fn,
{
QueryListener *ql;
- ql = gtk_type_new (QUERY_LISTENER_TYPE);
+ ql = g_object_new (QUERY_LISTENER_TYPE, NULL);
return query_listener_construct (ql,
obj_updated_fn,
@@ -111,9 +111,9 @@ query_listener_init (QueryListener *ql)
priv->notify = TRUE;
}
-/* Destroy handler for the live search query listener */
+/* Finalize handler for the live search query listener */
static void